from libkeryx import definition
from libkeryx.tables import Project
from sqlalchemy import *
from sqlalchemy.orm import relation, backref
                                                                                          
class Relation(definition.Base):
    """Project relationships to repositories"""
    __tablename__ = "relations"
    
    id = Column(Integer, primary_key=True)
    project_id = Column(Integer, ForeignKey("projects.id"))
    type = Column(String) # installed/removed/etc
    target_id = Column(Integer)
    status = Column(String)
    
    project = relation(Project, backref=backref('relations', order_by=id))
    
    def __init__(self, type, target_id, status=None):
        #self.project_id = project_id
        self.type = type
        self.target_id = target_id
        self.status = status
        
    def __repr__(self):
        return "<Relation('%s','%s','%s','%s')>" % (self.project_id, self.type,
                                            self.target_id, self.status)

class Install(definition.Base):
    """Project relationships to repositories"""
    __tablename__ = "install"
    
    id = Column(Integer, primary_key=True)
    project_id = Column(Integer, ForeignKey("projects.id"))
    #type = Column(String) # installed/removed/etc
    package = Column(String)
    status = Column(String)
    
    project = relation(Project, backref=backref('install', order_by=id))
    
    def __init__(self, package, status):
        #self.project_id = project_id
        self.package = package
        self.status = status
        
    def __repr__(self):
        return "<Install('%s','%s','%s')>" % (self.project_id,
                                            self.package, self.status)

class Status(definition.Base):
    """Project status file storage"""
    __tablename__ = "status"
    
    id = Column(Integer, primary_key=True)
    proj_id = Column(Integer, ForeignKey("projects.id"))
    name = Column(String)
    version = Column(String)

    project = relation(Project, backref=backref('status', order_by=id))

    def __init__(self, name, version):
        self.name = name
        self.version = version
        
    def __repr__(self):
        return "<Status('%s','%s','%s')>" % (self.proj_id, self.name, self.version)

class Repo(definition.Base):
    """Table for storing repository urls"""
    __tablename__ = "repos"
    
    id = Column(Integer, primary_key=True)
    type = Column(String) #deb, deb-src, etc
    url = Column(String)
    dist = Column(String)
    sections = Column(String)

    def __init__(self, type, url, dist, sections):
        self.type = type
        self.url = url
        self.dist = dist
        self.sections = sections

    def __repr__(self):
        return "<Repo('%s','%s','%s','%s')>" % (self.type, self.url, self.dist, 
                                      self.sections)
  
    def items(self):
        return [self.type, self.url, self.dist, self.sections]

class Package(definition.Base):
    """Table for holding package metadata"""
    __tablename__ = "packages"
    
    id = Column(Integer, primary_key=True)
    name = Column(Unicode)
    version = Column(Unicode)
    section = Column(Unicode)
    installed_size = Column(Unicode)
    maintainer = Column(Unicode)
    original_maintainer = Column(Unicode)
    architecture = Column(Unicode)
    replaces = Column(Unicode)
    provides = Column(Unicode)
    depends = Column(Unicode)
    recommends = Column(Unicode)
    suggests = Column(Unicode)
    conflicts = Column(Unicode)
    filename = Column(Unicode)
    size = Column(Unicode)
    md5sum = Column(Unicode)
    sha256 = Column(Unicode)
    shortdesc = Column(Unicode)
    longdesc = Column(Unicode)
    homepage = Column(Unicode)
    bugs = Column(Unicode)
    origin = Column(Unicode)
    task = Column(Unicode)

    def __init__(self, name, version, section, \
                 installed_size, maintainer, original_maintainer, \
                 architecture, replaces):#, replaces, provides, depends, recommends, \
                 #suggests, conflicts, filename, size, md5sum, sha256, \
                 #shortdesc, longdesc, homepage, bugs, origin, task):
        self.name = name
        self.version = version
        self.section = section
        self.installed_size = installed_size
        self.maintainer = maintainer
        self.original_maintainer = original_maintainer
        self.architecture = architecture
        self.replaces = replaces
        #self.provides = provides
        #self.depends = depends
        #self.recommends = recommends
        #self.suggests = suggests
        #self.conflicts = conflicts
        #self.filename = filename
        #self.size = size
        #self.md5sum = md5sum
        #self.sha256 = sha256
        #self.shortdesc = shortdesc
        #self.longdesc = longdesc
        #self.homepage = homepage
        #self.bugs = bugs
        #self.origin = origin
        #self.task = task

    def __repr__(self):
        return "<Package('%s','%s','%s','%s','%s','%s','%s','%s','%s')>" % \
            (self.id, self.name, self.version, self.section,
             self.installed_size, self.maintainer, self.original_maintainer,
             self.architecture, self.replaces,
            )
#    def __repr__(self):
#        return "<Package('%s','%s','%s','%s','%s','%s','%s','%s'" \
#               ",'%s','%s','%s','%s','%s','%s','%s','%s','%s','%s'" \
#               ",'%s','%s','%s','%s','%s')>" % \
#                (self.id, self.name, self.version, self.section,
#                 self.installed_size, self.maintainer, self.original_maintainer,
#                 self.architecture, self.replaces, self.provides, self.depends,
#                 self.recommends, self.suggests, self.conflicts, self.filename,
#                 self.size, self.md5sum, self.sha256, self.shortdesc, 
#                 self.longdesc, self.homepage, self.bugs, self.origin, 
#                 self.task)

